# -*- coding:utf-8 -*-

query = 'https://www.wikidata.org/w/api.php?action=wbgetentities&formatversion=2&languages=en&props=labels&redirects=yes&ids=P4193|P119|Q14623673|P691|P856|P18|P1559|P3373|P2048|P509|P569|P345|P1006|P349|P1005|P1003|P2611|P2191|Q12152|P109|P108|Q42406|P106|Q3739104|P269|P103|P25|P27|P26|P21|P20|P22|P866|Q6581097|Q691283|P2188|P646|Q7979|Q28389|Q4853732|P800|P373|P648|Q128758|Q14623681|P2626|P1233|P1442|P570|Q1042294'

response = r"""{
    "entities": {
        "P4193": {
            "type": "property",
            "datatype": "external-id",
            "id": "P4193",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Familypedia person ID"
                }
            }
        },
        "P119": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P119",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "place of interment"
                }
            }
        },
        "Q14623673": {
            "type": "item",
            "id": "Q14623673",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Susan Adams"
                }
            }
        },
        "P691": {
            "type": "property",
            "datatype": "external-id",
            "id": "P691",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "NKCR AUT ID"
                }
            }
        },
        "P856": {
            "type": "property",
            "datatype": "url",
            "id": "P856",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "official website"
                }
            }
        },
        "P18": {
            "type": "property",
            "datatype": "commonsMedia",
            "id": "P18",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "image"
                }
            }
        },
        "P1559": {
            "type": "property",
            "datatype": "monolingualtext",
            "id": "P1559",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "name in native language"
                }
            }
        },
        "P3373": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P3373",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "sibling"
                }
            }
        },
        "P2048": {
            "type": "property",
            "datatype": "quantity",
            "id": "P2048",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "height"
                }
            }
        },
        "P509": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P509",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "cause of death"
                }
            }
        },
        "P569": {
            "type": "property",
            "datatype": "time",
            "id": "P569",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "date of birth"
                }
            }
        },
        "P345": {
            "type": "property",
            "datatype": "external-id",
            "id": "P345",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "IMDb ID"
                }
            }
        },
        "P1006": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1006",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "National Thesaurus for Author Names ID"
                }
            }
        },
        "P349": {
            "type": "property",
            "datatype": "external-id",
            "id": "P349",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "NDL Auth ID"
                }
            }
        },
        "P1005": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1005",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "PTBNP ID"
                }
            }
        },
        "P1003": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1003",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "NLR (Romania) ID"
                }
            }
        },
        "P2611": {
            "type": "property",
            "datatype": "external-id",
            "id": "P2611",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "TED speaker ID"
                }
            }
        },
        "P2191": {
            "type": "property",
            "datatype": "external-id",
            "id": "P2191",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "NILF author id"
                }
            }
        },
        "Q12152": {
            "type": "item",
            "id": "Q12152",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "myocardial infarction"
                }
            }
        },
        "P109": {
            "type": "property",
            "datatype": "commonsMedia",
            "id": "P109",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "signature"
                }
            }
        },
        "P108": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P108",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "employer"
                }
            }
        },
        "Q42406": {
            "type": "item",
            "id": "Q42406",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "English people"
                }
            }
        },
        "P106": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P106",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "occupation"
                }
            }
        },
        "Q3739104": {
            "type": "item",
            "id": "Q3739104",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "natural causes"
                }
            }
        },
        "P269": {
            "type": "property",
            "datatype": "external-id",
            "id": "P269",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "SUDOC authorities"
                }
            }
        },
        "P103": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P103",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "native language"
                }
            }
        },
        "P25": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P25",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "mother"
                }
            }
        },
        "P27": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P27",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "country of citizenship"
                }
            }
        },
        "P26": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P26",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "spouse"
                }
            }
        },
        "P21": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P21",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "sex or gender"
                }
            }
        },
        "P20": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P20",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "place of death"
                }
            }
        },
        "P22": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P22",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "father"
                }
            }
        },
        "P866": {
            "type": "property",
            "datatype": "external-id",
            "id": "P866",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Perlentaucher ID"
                }
            }
        },
        "Q6581097": {
            "type": "item",
            "id": "Q6581097",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "male"
                }
            }
        },
        "Q691283": {
            "type": "item",
            "id": "Q691283",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "St John's College"
                }
            }
        },
        "P2188": {
            "type": "property",
            "datatype": "external-id",
            "id": "P2188",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "BiblioNet author ID"
                }
            }
        },
        "P646": {
            "type": "property",
            "datatype": "external-id",
            "id": "P646",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Freebase ID"
                }
            }
        },
        "Q7979": {
            "type": "item",
            "id": "Q7979",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "British English"
                }
            }
        },
        "Q28389": {
            "type": "item",
            "id": "Q28389",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "screenwriter"
                }
            }
        },
        "Q4853732": {
            "type": "item",
            "id": "Q4853732",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "children's writer"
                }
            }
        },
        "P800": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P800",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "notable work"
                }
            }
        },
        "P373": {
            "type": "property",
            "datatype": "string",
            "id": "P373",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Commons category"
                }
            }
        },
        "P648": {
            "type": "property",
            "datatype": "external-id",
            "id": "P648",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Open Library ID"
                }
            }
        },
        "Q128758": {
            "type": "item",
            "id": "Q128758",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "satire"
                }
            }
        },
        "Q14623681": {
            "type": "item",
            "id": "Q14623681",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Jane Belson"
                }
            }
        },
        "P2626": {
            "type": "property",
            "datatype": "external-id",
            "id": "P2626",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "DNF person ID"
                }
            }
        },
        "P1233": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1233",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "ISFDB author ID"
                }
            }
        },
        "P1442": {
            "type": "property",
            "datatype": "commonsMedia",
            "id": "P1442",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "image of grave"
                }
            }
        },
        "P570": {
            "type": "property",
            "datatype": "time",
            "id": "P570",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "date of death"
                }
            }
        },
        "Q1042294": {
            "type": "item",
            "id": "Q1042294",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "So Long, and Thanks for All the Fish"
                }
            }
        }
    },
    "success": 1
}"""

cache = {'info': {'status': 200}, 'query': query, 'response': response}
