# -*- coding:utf-8 -*-

query = 'https://www.wikidata.org/w/api.php?action=wbgetentities&formatversion=2&languages=en&props=labels&redirects=yes&ids=Q6607|Q7758404|P271|P172|Q902712|P31|P409|Q84|Q578895|P1258|P2435|P244|Q350|P213|Q533697|P3430|P1670|P40|P1695|Q5|P2019|P268|P551|Q245068|P396|P906|P3222|Q909993|P734|P735|P1477|P1368|P140|Q18844224|P2163|P3417|Q9531|P3106|P4431|P69|Q3414212|P227|P949|P947|P1617|P19|P1196'

response = r"""{
    "entities": {
        "Q6607": {
            "type": "item",
            "id": "Q6607",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "guitar"
                }
            }
        },
        "Q7758404": {
            "type": "item",
            "id": "Q7758404",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "The Private Life of Genghis Khan"
                }
            }
        },
        "P271": {
            "type": "property",
            "datatype": "external-id",
            "id": "P271",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "CiNii author ID"
                }
            }
        },
        "P172": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P172",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "ethnic group"
                }
            }
        },
        "Q902712": {
            "type": "item",
            "id": "Q902712",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Dirk Gently's Holistic Detective Agency"
                }
            }
        },
        "P31": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P31",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "instance of"
                }
            }
        },
        "P409": {
            "type": "property",
            "datatype": "external-id",
            "id": "P409",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "NLA (Australia) ID"
                }
            }
        },
        "Q84": {
            "type": "item",
            "id": "Q84",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "London"
                }
            }
        },
        "Q578895": {
            "type": "item",
            "id": "Q578895",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "The Restaurant at the End of the Universe"
                }
            }
        },
        "P1258": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1258",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Rotten Tomatoes ID"
                }
            }
        },
        "P2435": {
            "type": "property",
            "datatype": "external-id",
            "id": "P2435",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "PORT person ID"
                }
            }
        },
        "P244": {
            "type": "property",
            "datatype": "external-id",
            "id": "P244",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Library of Congress authority ID"
                }
            }
        },
        "Q350": {
            "type": "item",
            "id": "Q350",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Cambridge"
                }
            }
        },
        "P213": {
            "type": "property",
            "datatype": "external-id",
            "id": "P213",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "ISNI"
                }
            }
        },
        "Q533697": {
            "type": "item",
            "id": "Q533697",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Highgate Cemetery"
                }
            }
        },
        "P3430": {
            "type": "property",
            "datatype": "external-id",
            "id": "P3430",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "SNAC Ark ID"
                }
            }
        },
        "P1670": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1670",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "LAC ID"
                }
            }
        },
        "P40": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P40",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "child"
                }
            }
        },
        "P1695": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1695",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "NLP ID"
                }
            }
        },
        "Q5": {
            "type": "item",
            "id": "Q5",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "human"
                }
            }
        },
        "P2019": {
            "type": "property",
            "datatype": "external-id",
            "id": "P2019",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "AllMovie artist ID"
                }
            }
        },
        "P268": {
            "type": "property",
            "datatype": "external-id",
            "id": "P268",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "BnF ID"
                }
            }
        },
        "P551": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P551",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "residence"
                }
            }
        },
        "Q245068": {
            "type": "item",
            "id": "Q245068",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "comedian"
                }
            }
        },
        "P396": {
            "type": "property",
            "datatype": "external-id",
            "id": "P396",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "SBN ID"
                }
            }
        },
        "P906": {
            "type": "property",
            "datatype": "external-id",
            "id": "P906",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "SELIBR"
                }
            }
        },
        "P3222": {
            "type": "property",
            "datatype": "external-id",
            "id": "P3222",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "NE.se ID"
                }
            }
        },
        "Q909993": {
            "type": "item",
            "id": "Q909993",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Brentwood"
                }
            }
        },
        "P734": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P734",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "family name"
                }
            }
        },
        "P735": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P735",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "given name"
                }
            }
        },
        "P1477": {
            "type": "property",
            "datatype": "monolingualtext",
            "id": "P1477",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "birth name"
                }
            }
        },
        "P1368": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1368",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "LNB ID"
                }
            }
        },
        "P140": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P140",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "religion"
                }
            }
        },
        "Q18844224": {
            "type": "item",
            "id": "Q18844224",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "science fiction writer"
                }
            }
        },
        "P2163": {
            "type": "property",
            "datatype": "external-id",
            "id": "P2163",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "FAST ID"
                }
            }
        },
        "P3417": {
            "type": "property",
            "datatype": "external-id",
            "id": "P3417",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Quora topic ID"
                }
            }
        },
        "Q9531": {
            "type": "item",
            "id": "Q9531",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "BBC"
                }
            }
        },
        "P3106": {
            "type": "property",
            "datatype": "external-id",
            "id": "P3106",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Guardian topic ID"
                }
            }
        },
        "P4431": {
            "type": "property",
            "datatype": "external-id",
            "id": "P4431",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Google Doodle"
                }
            }
        },
        "P69": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P69",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "educated at"
                }
            }
        },
        "Q3414212": {
            "type": "item",
            "id": "Q3414212",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "Hugo Award for Best Dramatic Presentation"
                }
            }
        },
        "P227": {
            "type": "property",
            "datatype": "external-id",
            "id": "P227",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "GND ID"
                }
            }
        },
        "P949": {
            "type": "property",
            "datatype": "external-id",
            "id": "P949",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "National Library of Israel ID"
                }
            }
        },
        "P947": {
            "type": "property",
            "datatype": "external-id",
            "id": "P947",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "RSL ID (person)"
                }
            }
        },
        "P1617": {
            "type": "property",
            "datatype": "external-id",
            "id": "P1617",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "BBC Things ID"
                }
            }
        },
        "P19": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P19",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "place of birth"
                }
            }
        },
        "P1196": {
            "type": "property",
            "datatype": "wikibase-item",
            "id": "P1196",
            "labels": {
                "en": {
                    "language": "en",
                    "value": "manner of death"
                }
            }
        }
    },
    "success": 1
}"""

cache = {'info': {'status': 200}, 'query': query, 'response': response}
